/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNfij for the 3D integration at all eps-orders and the alpha^-1 order of the pseudo-nf structure. 
 * Example: PNfI3EP1AM1 ('P'seudo-'Nf' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'P'lus '1'st and 'A'lpha to the 'M'inus '1'st order) 
 * contains logs of FXi functions evaluated at z=0,x=0,s5=0, i.e. with the deltas from all +-distributions, multiplied 
 * with the correct XPNf functions to arrive at eps^1 alpha^-1. 
 */

#include <Auxiliaries.h>
#include <3IntPNFAM1.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>

double PNfI3EM2AM1(double w,double s6,double c) {
	return (pow(m,-1)*XPNf00(w,s6,0,0,c))/2.;
}

double PNfI3EM1AM1(double w,double s6,double c) {
	return (pow(m,-1)*((log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf00(w,s6,0,0,c) +
		       XPNf01(w,s6,0,0,c)))/2.;
}

double PNfI3E0AM1(double w,double s6,double c) {
	return (pow(m,-1)*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
	        XPNf00(w,s6,0,0,c) + (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf01(w,s6,0,0,c) +
	       XPNf02(w,s6,0,0,c)))/2.;
}

double PNfI3EP1AM1(double w,double s6,double c) {
	return (pow(m,-1)*(8*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*
	        XPNf00(w,s6,0,0,c) + 3*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) +
	             pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNf01(w,s6,0,0,c) + (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) +
	             log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf02(w,s6,0,0,c) + XPNf03(w,s6,0,0,c))))/6.;
}


