/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XNfij for the 4D integration at all eps-orders and the alpha^-1 order of the nf structure. 
 * Example: NfI4EP1AM1s ('Nf' structure, 'I'ntegration over '4' dimensions, at 'E'ps to the 'Plus '1'st and 'A'lpha to the 'M'inus '1'st order, fourth integration over 's'5) 
 * contains logs of FXi functions evaluated at z=0,x=0, i.e. with the deltas from all +-distributions except the t5/s5 one, multiplied 
 * with the correct XNf functions to arrive at eps^1 alpha^-1. 
 */
#include <4IntNFAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorNf.h>
#include <Input_Common.h>

//fourth integration is over x irrelevant, no 1/alpha

//fourth integration is over s5

double NfI4EM1AM1s(double w,double s6,double s5,double c) {
	return pow(m,-1)*pow(s5,-1)*(XNf00(w,s6,0,0,c) - XNf00(w,s6,s5,0,c));
}

double NfI4E0AM1s(double w,double s6,double s5,double c) {
	return pow(m,-1)*pow(s5,-1)*((-2*log(s5) + log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*
		      XNf00(w,s6,0,0,c) + (2*log(s5) - log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))) -
		        log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))))*XNf00(w,s6,s5,0,c) + XNf01(w,s6,0,0,c) - XNf01(w,s6,s5,0,c));
}

double NfI4EP1AM1s(double w,double s6,double s5,double c) {
	return pow(m,-1)*pow(s5,-1)*(2*(-(log(s5)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))) +
	        pow(log(s5),2) + pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))
	       *XNf00(w,s6,0,0,c) - 2*(-(log(s5)*(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))) + log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))) + log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))) +
	             log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))))) + pow(log(s5),2) + pow(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))),2) +
	        pow(log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))),2))*XNf00(w,s6,s5,0,c) - 2*log(s5)*XNf01(w,s6,0,0,c) +
	     log(FA1(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) + log(FA2(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) + log(FB1(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) +
	     log(FB2(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) + 2*log(s5)*XNf01(w,s6,s5,0,c) - log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XNf01(w,s6,s5,0,c) -
	     log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XNf01(w,s6,s5,0,c) - log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XNf01(w,s6,s5,0,c) - log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XNf01(w,s6,s5,0,c) +
	     XNf02(w,s6,0,0,c) - XNf02(w,s6,s5,0,c));
}

//fourth integration is over z

double NfI4EM1AM1z(double w,double s6,double z,double c) {
	return 2*pow(m,-1)*pow(z,-1)*(XNf00(w,s6,0,0,c) - XNf00(w,s6,0,z,c));
}

double NfI4E0AM1z(double w,double s6,double z,double c) {
	return -2*pow(m,-1)*pow(z,-1)*((4*log(z) - log(FA1(v(w),tl(s6),0,0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) - log(FB1(v(w),tl(s6),0,0,0,b(c))) - log(FB2(v(w),tl(s6),0,0,0,b(c))))*
		      XNf00(w,s6,0,0,c) + (-4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),b(c))) + log(FA2(v(w),tl(s6),0,0,u(z),b(c))) + log(FB1(v(w),tl(s6),0,0,u(z),b(c))) + log(FB2(v(w),tl(s6),0,0,u(z),b(c))))*
		      XNf00(w,s6,0,z,c) - XNf01(w,s6,0,0,c) + XNf01(w,s6,0,z,c));
}

double NfI4EP1AM1z(double w,double s6,double z,double c) {
	return 2*pow(m,-1)*pow(z,-1)*(2*(-2*log(z)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c)))) +
	        4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2)
	        )*XNf00(w,s6,0,0,c) - 2*(-2*log(z)*(log(FA1(v(w),tl(s6),0,0,u(z),b(c))) + log(FA2(v(w),tl(s6),0,0,u(z),b(c))) + log(FB1(v(w),tl(s6),0,0,u(z),b(c))) +
	           log(FB2(v(w),tl(s6),0,0,u(z),b(c)))) + 4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),b(c))),2) +
	        pow(log(FB1(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),b(c))),2))*XNf00(w,s6,0,z,c) - 4*log(z)*XNf01(w,s6,0,0,c) +
	     log(FA1(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) + log(FA2(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) + log(FB1(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) +
	     log(FB2(v(w),tl(s6),0,0,0,b(c)))*XNf01(w,s6,0,0,c) + 4*log(z)*XNf01(w,s6,0,z,c) - log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XNf01(w,s6,0,z,c) -
	     log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XNf01(w,s6,0,z,c) - log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XNf01(w,s6,0,z,c) - log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XNf01(w,s6,0,z,c) +
	     XNf02(w,s6,0,0,c) - XNf02(w,s6,0,z,c));
}
