/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 2D integration at all eps-orders and alpha^-2 order of the Cf^2 structure, subregion a. 
 * Example: I2EM1AM2 ('I'ntegration over '2' dimensions, at 'E'ps to the 'M'inus '1'st and 'A'lpha to the 'M'inus '2'nd order) contains various logs of FXi functions
 * evaluated at x=0,r=0,c=0,s5=0, i.e. with all the deltas from +-distributions, multiplied with the correct X functions' eps- and alpha-powers to arrive at 
 * eps^-1 alpha^-2. 
 */

#include <2IntAM2.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I2EM2AM2(double s,double s6) {
	return pow(mexp,-2)*XCfE0A0(s,0,s6);
}

double I2EM1AM2(double s,double s6) {
	return pow(mexp,-2)*((log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*
		      XCfE0A0(s,0,s6) + XCfE1A0(0,0,s,0,s6));
}

double I2E0AM2(double s,double s6) {
	return pow(mexp,-2)*(2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE0A0(s,0,s6) +
	     (log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*
	      XCfE1A0(0,0,s,0,s6) + XCfE2A0(0,0,s,0,s6));
}

double I2E1AM2(double s,double s6) {
	return (pow(mexp,-2)*(8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3))*XCfE0A0(s,0,s6) +
	       3*(2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
	             pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE1A0(0,0,s,0,s6) +
	          (log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*
	           XCfE2A0(0,0,s,0,s6) + XCfE3A0(0,0,s,0,s6))))/3.;
}

double I2E2AM2(double s,double s6) {
	return (pow(mexp,-2)*(8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),4) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),4) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),4) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),4))*XCfE0A0(s,0,s6) +
	       8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3))*XCfE1A0(0,0,s,0,s6) +
	       3*(2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
	             pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE2A0(0,0,s,0,s6) +
	          (log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*
	           XCfE3A0(0,0,s,0,s6) + XCfE4A0(0,0,s,0,s6))))/3.;
}
