/*
 * This file contains the (eps,alpha)-expansion of all functions and expressions in the Cf^2 colour structure, subregion b that are neither +-distributions or measurement functions 
 * (i.e. mainly structures from Jacobians and matrix element numerators, and non-divergent denominator structures), collected into one container X. The 
 * (eps,alpha)-expansion orders of this container appear in the differences generated by +-distributions and multiply the Logs of the measurement functions. They are 
 * constructed by substitution of variables in such a way to vanish at all non-critical boundaries (i.e. boundaries that have diverging logs attached, like 
 * Log(s6) at 0 or Log(1-s) at 1. As C++ sees x*Log(x) as 0*NaN, these have to be caught via if-clauses for all but the first regulator-order.
 * The notation is such that XCfEiAj is the eps^i alpha^j order of the X-container for colour structure Cf^2, subregion a.
 */

#include <XFactor.h>
#include <cmath>
#include <Auxiliaries.h>
#include <Input_Common.h>
using namespace std;

double XCfE0A0(double s,double s5, double s6) {
	return (1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(1 + pow(s,2))*(1 + pow(s6,2))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*
			   pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5);
}

double XCfE1A0(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return -((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) +
			       4*log(1 + pow(s,2)) + log(2 - pow(s,4)) + log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) +
			       log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)))*(1 + pow(s,2))*(1 + pow(s6,2))*pow(2 - pow(s,4),-0.5)*
			     pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5));
	}
}

double XCfE2A0(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return ((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(1 + pow(s,2))*(1 + pow(s6,2))*
			     pow(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) + 4*log(1 + pow(s,2)) + log(2 - pow(s,4)) +
			       log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) + log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)),2)*
			     pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
			     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/2.;
	}
}

double XCfE3A0(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return -((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(1 + pow(s,2))*(1 + pow(s6,2))*
			      pow(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) + 4*log(1 + pow(s,2)) + log(2 - pow(s,4)) +
			        log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) + log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)),3)*
			      pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
			      pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/6.;
	}
}

double XCfE4A0(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return ((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(1 + pow(s,2))*(1 + pow(s6,2))*
			     pow(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) + 4*log(1 + pow(s,2)) + log(2 - pow(s,4)) +
			       log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) + log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)),4)*
			     pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
			     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/24.;
	}
}

double XCfE0A1(double xk,double xl,double s,double s5, double s6) {
	return -((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(log(1 + pow(xk,mexp)) + log(1 + pow(xl,mexp)))*(1 + pow(s,2))*(1 + pow(s6,2))*pow(2 - pow(s,4),-0.5)*
		     pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5));
}

double XCfE1A1(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return (1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) +
			     4*log(1 + pow(s,2)) + log(2 - pow(s,4)) + log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) + log(2 - pow(s6,4)) +
			     log(2 - 2*pow(s6,4) + pow(s6,8)))*(log(1 + pow(xk,mexp)) + log(1 + pow(xl,mexp)))*(1 + pow(s,2))*(1 + pow(s6,2))*pow(2 - pow(s,4),-0.5)*
			   pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5);
	}
}

double XCfE2A1(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return -((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(log(1 + pow(xk,mexp)) + log(1 + pow(xl,mexp)))*(1 + pow(s,2))*(1 + pow(s6,2))*
			      pow(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) + 4*log(1 + pow(s,2)) + log(2 - pow(s,4)) +
			        log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) + log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)),2)*
			      pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
			      pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/2.;
	}
}

double XCfE3A1(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return ((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(log(1 + pow(xk,mexp)) + log(1 + pow(xl,mexp)))*(1 + pow(s,2))*(1 + pow(s6,2))*
			     pow(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) + 4*log(1 + pow(s,2)) + log(2 - pow(s,4)) +
			       log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) + log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)),3)*
			     pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
			     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/6.;
	}
}

double XCfE0A2(double xk,double xl,double s,double s5, double s6) {
	return ((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(1 + pow(s,2))*(1 + pow(s6,2))*pow(log(1 + pow(xk,mexp)) + log(1 + pow(xl,mexp)),2)*pow(2 - pow(s,4),-0.5)*
		     pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/2.;
}

double XCfE1A2(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return -((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) +
		        4*log(1 + pow(s,2)) + log(2 - pow(s,4)) + log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) +
		        log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)))*(1 + pow(s,2))*(1 + pow(s6,2))*pow(log(1 + pow(xk,mexp)) + log(1 + pow(xl,mexp)),2)*
		      pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
		      pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/2.;
	}
}

double XCfE2A2(double xk,double xl,double s,double s5, double s6) {
	if(s6>=1. || s6<=0. || s<=0. || s>=1.) {
		return 0;
	} else {
		return ((1 - s)*s*(1 + s)*(1 - s6)*s6*(1 + s6)*(1 + pow(s,2))*(1 + pow(s6,2))*
			     pow(4*log(1 - s) + 4*log(s) + 4*log(1 + s) + 4*log(1 - s6) + 4*log(s6) + 4*log(1 + s6) + 4*log(1 + pow(s,2)) + log(2 - pow(s,4)) +
			       log(2 - 2*pow(s,4) + pow(s,8)) + log(2 - pow(s5,2)) + 4*log(1 + pow(s6,2)) + log(2 - pow(s6,4)) + log(2 - 2*pow(s6,4) + pow(s6,8)),2)*
			     pow(log(1 + pow(xk,mexp)) + log(1 + pow(xl,mexp)),2)*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5)*pow(2 - pow(s5,2),-1)*
			     pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5))/4.;
	}
}

